# If you use PyFBA please cite:

[Cuevas DA, Garza D, Sanchez SE, Rostron J, Henry CS, Vonstein V, Overbeek RA, Segall A, Rohwer F, Dinsdale EA, Edwards RA. 2014. 
Elucidating genomic gaps using phenotypic profiles. 
F1000Research. 3:210 doi: 10.12688/f1000research.5140.2](https://f1000research.com/articles/3-210)


[Cuevas, Daniel A., Janaka Edirisinghe, Chris S. Henry, Ross Overbeek, Taylor G. O’Connell, and Robert A. Edwards. 2016.
From DNA to FBA: How to Build Your Own Genome-Scale Metabolic Model.
Frontiers in Microbiology 7 (June): 907.](http://journal.frontiersin.org/article/10.3389/fmicb.2016.00907/full)

The model SEED is used extensively by PyFBA and its citation is 

[Henry CS, DeJongh M, Best AA, Frybarger PM, Linsay B, Stevens RL. 2010. 
High-throughput generation, optimization and analysis of genome-scale metabolic models. 
Nat Biotechnol 28:977–982](https://www.nature.com/articles/nbt.1672)